@@ -1,8 +1,8 @@
+"""MLDOCK CLI MAIN ENTRYPOINT SCIPT"""
 # -*- coding: utf-8 -*-
 from __future__ import print_function, unicode_literals
 
 import os
-import sys
 import click
 
 from mldock.__version__ import __version__
@@ -12,6 +12,7 @@ from mldock.command.configure import configure
 from mldock.command.local import local
 from mldock.command.registry import registry
 from mldock.command.templates import templates
+from mldock.command.logs import logs
 from mldock.log import configure_logger
 
 click.disable_unicode_literals_warning = True
@@ -32,15 +33,21 @@ def cli(ctx, verbose):
     logger.info(CLI_VERSION)
     ctx.obj = {'verbose': verbose, 'mldock_package_path': mldock_package_path, 'logo': MLDOCK_LOGO}
 
-def add_commands(cli):
-
-    cli.add_command(configure)
-    cli.add_command(container)
-    cli.add_command(local)
-    cli.add_command(registry)
-    cli.add_command(templates)
+def add_commands(cli_group: click.group):
+    """
+        add commands to cli group
+        args:
+            cli (click.group)
+    """
+    cli_group.add_command(configure)
+    cli_group.add_command(container)
+    cli_group.add_command(local)
+    cli_group.add_command(registry)
+    cli_group.add_command(templates)
+    cli_group.add_command(logs)
 
 add_commands(cli)
 
 if __name__ == '__main__':
+    # pylint: disable=no-value-for-parameter
     cli()
