@@ -6,13 +6,15 @@
         - mldock
 """
 import os
-import json
-import click
+import sys
 import logging
 from pathlib import Path
+import click
 
 from mldock.terminal import ChoiceWithNumbers, style_dropdown
 from mldock.config_managers.core import BaseConfigManager
+from mldock.platform_helpers.mldock import utils as mldock_utils
+from mldock.platform_helpers import utils
 
 logger=logging.getLogger('mldock')
 
@@ -34,22 +36,49 @@ class MLDockConfigManager(BaseConfigManager):
     }
 
     def __init__(self, filepath: str, create: bool = False):
+        # dealing with weird os related path formats
+        super().__init__()
         self.filepath = filepath
-        self.image_name_default = Path(filepath).parents[0].name
 
         config = self.load_config(self.filepath, create=create)
-        self.config.update(config)
-        self.config["image_name"] = self.image_name_default
 
-    def setup_config(self, **kwargs):
+        self.image_name_default = Path(filepath).parents[0].name
+
+        self.config.update(config)
+
+        if self.config.get("image_name", None) is None:
+            # if is None override with default
+            self.config["image_name"] = self.image_name_default
+
+    def check_if_exists_else_create(self, file_name: str, create: bool):
+        """check that mldock fileexists"""
+        if not self.file_exists(file_name):
+            if create:
+                # deal with possiblity of nested directory
+                utils._mkdir(Path(file_name).parents[0])
+                # create file
+                self.touch(file_name)
+            else:
+                logger.error((
+                    "No MLDOCK container project found with "
+                    "dir = '{CONTAINER_DIR}/'. Re-run `mldock container init` "
+                    "and Confirm 'yes' to create.".format(
+                        CONTAINER_DIR=Path(file_name).parents[0]
+                    )
+                ))
+                sys.exit(1)
+
+    def setup_config(self):
+        """run setup for configuration"""
         click.secho("Base Setup", bg='blue')
         self.ask_for_image_name()
         self.ask_for_template_name()
         self.ask_for_mldock_module_dir()
         self.ask_for_container_dir_name()
         self.ask_for_requirements_file_name()
-    
+
     def update_config(self, **kwargs):
+        """update configuration with given kwargs"""
         self.config.update(kwargs)
 
     def ask_for_image_name(self):
@@ -82,7 +111,7 @@ class MLDockConfigManager(BaseConfigManager):
             default=self.config.get('template', 'generic'),
             show_choices=False
         )
-        
+
         self.config.update({
             'template': template_name
         })
@@ -102,7 +131,7 @@ class MLDockConfigManager(BaseConfigManager):
     def ask_for_mldock_module_dir(self):
         """prompt user for mldock module dir
         """
-        
+
         mldock_module_dir = click.prompt(
             text=click.style("Set mldock module dir: ", fg='bright_blue'),
             default=self.config.get('mldock_module_dir', 'src')
@@ -111,7 +140,7 @@ class MLDockConfigManager(BaseConfigManager):
         self.config.update({
             'mldock_module_dir': mldock_module_dir
         })
-    
+
     @staticmethod
     def _format_data_node_item(item, base_path='data'):
 
@@ -122,7 +151,7 @@ class MLDockConfigManager(BaseConfigManager):
     def _format_data_node(self):
 
         output = []
-        
+
         for item in self.config['data']:
             output.append(self._format_data_node_item(item, base_path='data'))
 
@@ -131,7 +160,7 @@ class MLDockConfigManager(BaseConfigManager):
     def _format_model_node(self):
 
         output = []
-        
+
         for item in self.config['model']:
             output.append(self._format_data_node_item(item, base_path='model'))
 
@@ -140,7 +169,7 @@ class MLDockConfigManager(BaseConfigManager):
     def _format_stage_node(self):
 
         output = []
-        
+
         for key_, value_ in self.config['stages'].items():
             image_and_tag = "{}:{}".format(self.config['image_name'], value_["tag"])
             output.append("\t{} : {}".format(key_, image_and_tag))
@@ -151,7 +180,7 @@ class MLDockConfigManager(BaseConfigManager):
     def _format_nodes(config):
 
         output = []
-        
+
         for key_, value_ in config.items():
             output.append("\t{} : {}".format(key_, value_))
 
@@ -169,7 +198,12 @@ class MLDockConfigManager(BaseConfigManager):
         formatted_data_node = self._format_data_node()
         config.pop("model")
         formatted_model_node = self._format_model_node()
-        environment = config.pop("environment")
+        environment = {}
+        for key_, value_ in config.pop("environment").items():
+            mldock_key = mldock_utils._format_key_as_mldock_env_var(key_, prefix='mldock')
+            environment.update(
+                {mldock_key: value_}
+            )
 
         states = []
 
@@ -193,9 +227,9 @@ class MLDockConfigManager(BaseConfigManager):
         self.config.update({
             'requirements_dir':requirements_file_name
         })
-    
+
     def update_stages(self, stages: dict):
-        """"""
+        """update stages node in .mldock config"""
         self.config.update(
             {'stages': stages}
         )
@@ -232,7 +266,7 @@ class MLDockConfigManager(BaseConfigManager):
         self.config.update(
             {'data': data}
         )
-    
+
     def update_model_channels(self, models: dict):
         """
             Update data node in .mldock config
