@@ -3,15 +3,13 @@
 
     Handle Decoding of Content in to appropriate format from request as pandas dataframe.
 
-    e.g. 
+    e.g.
         list of lists -> pd.DataFrame.
 """
 import io
 import json
 import pandas as pd
 
-from mldock.platform_helpers.mldock.inference import content_types
-
 def csv_to_pandas(bytes_like: bytes):
     """
         Decodes byte encoded csv to pandas dataframe.
@@ -21,8 +19,8 @@ def csv_to_pandas(bytes_like: bytes):
         return:
             (pd.DataFrame): data as pandas dataframe
     """
-    s = bytes_like.decode()
-    data = io.StringIO(s)
+    string_like = bytes_like.decode()
+    data = io.StringIO(string_like)
     return pd.read_csv(data)
 
 def json_list_to_pandas(json_data):
@@ -36,5 +34,3 @@ def json_list_to_pandas(json_data):
     """
     data = json.loads(json_data)
     return pd.DataFrame(data)
-
-
